@@ -1,6 +1,6 @@
 from multiprocessing import Pool as ProcessPool
 from multiprocessing.dummy import Pool as ThreadPool
-from typing import Callable, Collection, Optional, Iterable, Any
+from typing import Callable, Collection, Optional, Iterable
 
 from alive_progress import alive_bar
 from gevent.pool import Pool as GeventPool
